@@ -44,8 +44,8 @@
 
 cluster.wild.plm<-function(mod, dat, cluster, ci.level = 0.95, boot.reps = 1000, report = TRUE, prog.bar = TRUE){
   
-  if( min( class(dat) != "pdata.frame" ) ){                           # if data not pdata.frame
-    dat <- pdata.frame(dat, index=colnames(dat)[1:2])                 # convert it
+  if( min( class(dat) != "pdata.frame" ) ){                             # if data not pdata.frame
+    dat <- pdata.frame(dat, index=colnames(dat)[1:2], row.names=F)      # convert it
   }
   
   if(cluster=="group"){                                               
